BBClient

Struct BBClient 

pub struct BBClient {
    pub cache_folder: PathBuf,
    pub bedbase_api: String,
    /* private fields */
}

Fields

cache_folder: PathBufbedbase_api: String

Implementations

Source

impl BBClient

pub fn new( cache_folder: Option<PathBuf>, bedbase_api: Option<String>, ) -> Result<Self>

BBClient to deal with download files from bedbase and caching them.

Arguments
  • cache_folder: path to local folder as cache of files from bedbase, if not given it will be the environment variable BBCLIENT_CACHE
  • bedbase_api: url to bedbase
pub fn load_bed(&mut self, bed_id: &str) -> Result<RegionSet>

Loads a BED file from cache, or downloads and caches it if it doesn’t exist

Arguments
  • bed_id: unique identifier of a BED file
Returns
  • the RegionSet object of the loaded bed file
pub fn load_bedset(&mut self, bedset_id: &str) -> Result<BedSet>

Load a BEDset from cache, or download and add it to the cache with its BED files

Arguments
  • bedset_id: unique identifier of a BED set
Returns
  • the BedSet object of the loaded bed set
pub fn add_local_bed_to_cache( &mut self, bedfile: PathBuf, force: Option<bool>, ) -> Result<String>

Add a BED file to the cache

Arguments
  • bedfile: a path or url to the BED file
  • force: whether to overwrite the existing file in cache
Returns
  • the RegionSet identifier
pub fn add_regionset_to_cache( &mut self, regionset: RegionSet, force: Option<bool>, ) -> Result<String>

Add a RegionSet object to the cache

Arguments
  • regionset: a RegionSet object
  • force: whether to overwrite the existing file in cache
Returns
  • the RegionSet identifier
pub fn add_bedset_to_cache(&mut self, bedset: BedSet) -> Result<String>

Add a BED set to the cache

Arguments
  • bedset: the BED set to be added, a BedSet class
Returns
  • the identifier if the BedSet object
pub fn add_local_folder_as_bedset( &mut self, folder_path: PathBuf, ) -> Result<String>

Add a folder of bed files to the cache as a bedset

Arguments
  • folder_path: path to the folder where bed files are stored
Returns
  • the identifier if the BedSet object
pub fn add_local_file_as_bedset(&mut self, file_path: PathBuf) -> Result<String>

Add a local file that contains bed file paths as a bed set

Arguments
  • file_path: path to the file of bedset info
Returns
  • the identifier if the BedSet object
pub fn seek(&self, identifier: &str) -> Result<PathBuf>

Get local path to BED file or BED set with specific identifier

Arguments
  • identifier: the unique identifier
Returns
  • the local path of the file
pub fn remove(&mut self, identifier: &str) -> Result<()>

Remove a BED file or BED set from the cache folder as well as biocfilcache (SQLite)

Arguments
  • identifier: the identifier of BED file / BED set to be removed
pub fn list_beds(&mut self) -> Result<Vec<Resource>>

List identifiers and paths of all BED files in cache

Returns
  • the list of resource stored in biocfilecache (identifiers & paths)
pub fn list_bedsets(&mut self) -> Result<Vec<Resource>>

List identifiers and paths of all BED sets in cache

Returns
  • the list of resource stored in biocfilecache (identifiers & paths)