pub struct BBClient {
pub cache_folder: PathBuf,
pub bedbase_api: String,
/* private fields */
}Fields
cache_folder: PathBufbedbase_api: StringImplementations
Sourceimpl BBClient
impl BBClient
Sourcepub fn new(
cache_folder: Option<PathBuf>,
bedbase_api: Option<String>,
) -> Result<Self>
pub fn new( cache_folder: Option<PathBuf>, bedbase_api: Option<String>, ) -> Result<Self>
BBClient to deal with download files from bedbase and caching them.
Arguments
- cache_folder: path to local folder as cache of files from bedbase,
if not given it will be the environment variable
BBCLIENT_CACHE - bedbase_api: url to bedbase
Sourcepub fn load_bedset(&mut self, bedset_id: &str) -> Result<BedSet>
pub fn load_bedset(&mut self, bedset_id: &str) -> Result<BedSet>
Sourcepub fn add_local_bed_to_cache(
&mut self,
bedfile: PathBuf,
force: Option<bool>,
) -> Result<String>
pub fn add_local_bed_to_cache( &mut self, bedfile: PathBuf, force: Option<bool>, ) -> Result<String>
Sourcepub fn add_regionset_to_cache(
&mut self,
regionset: RegionSet,
force: Option<bool>,
) -> Result<String>
pub fn add_regionset_to_cache( &mut self, regionset: RegionSet, force: Option<bool>, ) -> Result<String>
Sourcepub fn add_bedset_to_cache(&mut self, bedset: BedSet) -> Result<String>
pub fn add_bedset_to_cache(&mut self, bedset: BedSet) -> Result<String>
Sourcepub fn add_local_folder_as_bedset(
&mut self,
folder_path: PathBuf,
) -> Result<String>
pub fn add_local_folder_as_bedset( &mut self, folder_path: PathBuf, ) -> Result<String>
Sourcepub fn add_local_file_as_bedset(&mut self, file_path: PathBuf) -> Result<String>
pub fn add_local_file_as_bedset(&mut self, file_path: PathBuf) -> Result<String>
Sourcepub fn remove(&mut self, identifier: &str) -> Result<()>
pub fn remove(&mut self, identifier: &str) -> Result<()>
Remove a BED file or BED set from the cache folder as well as biocfilcache (SQLite)
Arguments
- identifier: the identifier of BED file / BED set to be removed